stinkbomb — Pyskool 1.1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »

# stinkbomb

Defines the `Stinkbomb` class.

class `stinkbomb.` `Stinkbomb`(stinkbomb_id, command_list_id, phases, stink_range)

  A stinkbomb.

  Parameters: | stinkbomb_id – The ID of the stinkbomb. command_list_id – The ID of the command list the stinkbomb will use. phases – The phases of animation the stinkbomb cloud will use. stink_range – The maximum distance from which the stinkbomb can be smelt.

  `drop`(x, y)

    Drop the stinkbomb at a given location.

    Parameters: | x – The x-coordinate of the location. y – The y-coordinate of the location.

  `get_command_list_id`(lesson_id)

    Return the ID of the command list used by the stinkbomb.

    Parameters: | lesson_id – The ID of the current lesson (ignored - stinkbombs do not follow a timetable).

  `move_cloud`()

    Animate the stinkbomb cloud. Any stinkbomb smeller in the vicinity of the stinkbomb will be alerted and open a nearby window if possible.

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »